searchNodes=[{"doc":"Genex makes it easy to write Evolutionary Algorithms in Elixir. The process of creating an algorithm in Genex can be thought of in three phases: Problem Definition Evolution Definition Algorithm Execution The Genex module contains the behaviour necessary to encode a problem the Genex Way. This module implements &quot;Phase 1&quot; of the three phase process used by Genex. Genex problems consist of a minimum of 3 and at most 6 functions. These functions: Define your solution space (genotype/0 and datatype/0). Define your objective function (fitness_function/1 and weights/0). Define your termination criteria (terminate?/1). Implementing a Problem A basic Genex problem consists of: genotype/0, fitness_function/1, and terminate?/1. To define your first problem, create a new module with use Genex and declare each of these functions: defmodule MyProblem do use Genex def genotype, do: Genotype.binary(10) def fitness_function(chromosome), do: Enum.sum(chromosome.genes) def terminate?(population), do: population.max_fitness == 10 end Running a Problem Genex injects a special function called run/1 into your problem definition. run/1 takes a number of optional configuration options you can use to change how your algorithm is executed (see configuration guide). To properly run your algorithm, open up iex and call MyProblem.run() or declare your module in .exs file and run mix run path/to/my_problem.exs. Configuring Algorithms Genex supports the following configuration options: :title: String title of your algorithm. Defaults to &quot;Genetic Algorithm&quot;. :population_size: Integer size of your initial population. :selection_type: Function selection strategy. Defaults to Genex.Selection.natural(). :crossover_type: Function crossover strategy. Defualts to Genex.Crossover.single_point(). :mutation_type: Function mutation strategy. Defaults to :none. :survival_selection_type: Function survival selection strategy. Defaults to Genex.Selection.natural(). :selection_rate: Float between 0 and 1 or Function. Defaults to 0.8. :mutation_rate: Float between 0 and 1 or Function. Defaults to 0.05. :survival_rate: Float between 0 and 1 or Function. Defaults to 1 - selection_rate. All of these options are passed to run/1 as a Keyword list. See Configuring Genex for more. Additional Utilities The problem definition contains a few additional utilities that you might find useful to use. To find out more, see Additional Utilities.","ref":"Genex.html","title":"Genex","type":"behaviour"},{"doc":"Function used to specify how genes are stored in the chromosome. Genex supports any structure that implements Enumerable. After each generation, the algorithm &quot;repairs&quot; broke chromosomes by calling collection on each chromosome in the population. This is because many of the functions in Enum explicitly return a List. This should be a reference to a function that accepts an Enum and returns an Enum. Most data structures come with a utility function for creating new versions from other types. An example is MapSet.new/1. Elixir&#39;s MapSet.new/1 accepts an Enum and returns a new MapSet. The default version of this function returns a function that returns itself. In other words, the default version of this function simply returns the current representation of the chromosome. Because of how some of the functions in Enum work, this will always be a List.","ref":"Genex.html#c:collection/0","title":"Genex.collection/0","type":"callback"},{"doc":"Evaluates a chromosome. The fitness function is your objective function(s). It is the function(s) you are trying to optimize. The fitness function will be used during an evolution to evaluate solutions against one another. Genex supports multiple objectives. You can optimize multiple objectives at once by returning an Enum of objectives calculated from the chromosome. It&#39;s important to note that chromosome is of type Chromosome.t. Typically you want to assess fitness based on the genes of the chromosome, so you must access the genes field of the struct.","ref":"Genex.html#c:fitness_function/1","title":"Genex.fitness_function/1","type":"callback"},{"doc":"Generates a random gene set. This function is called n times, where n is the size of your population, at the beginning of the genetic algorithm to define the initial population. It&#39;s important that this function return random values, otherwise your initial population will consist of entirely the same set of solutions. The genotype of your problem represents how solutions to problems are encoded. It&#39;s your solution space. Genex.Tools.Genotype implements several convenience functions for representing different types of solutions. See the Representing Solutions guide for information about the different ways to represent solutions with Genex.","ref":"Genex.html#c:genotype/0","title":"Genex.genotype/0","type":"callback"},{"doc":"Tests the population for some termination criteria. The termination criteria is assessed at the beginning of every generation. If termination criteria is met, the algorithm halts and returns the current population. Termination criteria assesses the entire population. The Population struct contains several convenience features you can use to determine when to halt your algorithms. You can stop on max fitness, generations, or some arbitrary feature determined from the population. Check out Crafting Termination Criteria to see more.","ref":"Genex.html#c:terminate?/1","title":"Genex.terminate?/1","type":"callback"},{"doc":"Returns initial weights associated with each objective. The weights associated with each objective represent how &quot;important&quot; each weight is to your final solution. Typically, you want to weigh objectives equally, so your weights will consist of all ones. The default implementation of this function returns 1. This represents a single objective maximization problem. To minimize the objective function, declare a weight of -1. You can also achieve this in the fitness function; however, declaring weights makes your algorithm more expressive and easier to follow.","ref":"Genex.html#c:weights/0","title":"Genex.weights/0","type":"callback"},{"doc":"Implementation of several popular crossover methods. Crossover is analagous to reproduction or biological crossover. Genex utilizes pairs of chromosomes to create offspring from the genetic material of parent chromosomes. Crossover happens with some probability P(c). Typically this is a high probability. The probability of crossover or crossover_rate as it is called in our case, determines the number of parents selected to breed for the next generation. See more on this in the Selection documentation. Crossover operators are generic. As with any optimization problem, no single method will be perfect. Genex offers a variety of crossover operators to experiment with; however, you may find that you need to write your own to fit your specific use case. You can do this by writing your own method and referencing it in the :crossover_type option. Each time a crossover takes place, 2 new children are created. These children then populate the children field of the Population struct before they are merged into the new population.","ref":"Genex.Tools.Crossover.html","title":"Genex.Tools.Crossover","type":"module"},{"doc":"Performs a blend crossover. This will blend genes according to some alpha between 0 and 1. Returns {%Chromosome{}, %Chromosome{}}. Parameters p1: Parent one. p2: Parent two. alpha: Float between 0 and 1 representing percentage of each parent to blend into children.","ref":"Genex.Tools.Crossover.html#blend/3","title":"Genex.Tools.Crossover.blend/3","type":"function"},{"doc":"Performs cut-on-worst crossover of p1 and p2. Returns {%Chromosome{}, %Chromosome{}}. Parameters p1: Parent one. p2: Parent two. heuristic: Function with arity 2 to measure &quot;badness&quot; of a gene. repair: Function specifying how to repair chromosome.","ref":"Genex.Tools.Crossover.html#cut_on_worst/4","title":"Genex.Tools.Crossover.cut_on_worst/4","type":"function"},{"doc":"Performs a messy single point crossover at random points. This crossover disregards the length of the chromosome and will often arbitrarily increase or decrease it&#39;s size. Returns {%Chromosome{}, %Chromosome{}}. Parameters p1: Parent one. p2: Parent two.","ref":"Genex.Tools.Crossover.html#messy_single_point/2","title":"Genex.Tools.Crossover.messy_single_point/2","type":"function"},{"doc":"Performs modified crossover of p1 and p2. Returns {%Chromosome{}, %Chromosome{}}. Parameters p1: Parent one. p2: Parent two. repair: Function specifying how to repair chromosome.","ref":"Genex.Tools.Crossover.html#modified/3","title":"Genex.Tools.Crossover.modified/3","type":"function"},{"doc":"Performs multi-point crossover of p1 and p2. Returns {%Chromosome{}, %Chromosome{}}. Parameters p1: Parent one. p2: Parent two. n: Number of crossover points.","ref":"Genex.Tools.Crossover.html#multi_point/3","title":"Genex.Tools.Crossover.multi_point/3","type":"function"},{"doc":"Performs Order One (Davis Order) crossover of a random slice. Note: This algorithm only works if your encoding is a permutation. Returns {%Chromosome{}, %Chromosome{}}. Parameters p1: Parent one. p2: Parent two.","ref":"Genex.Tools.Crossover.html#order_one/2","title":"Genex.Tools.Crossover.order_one/2","type":"function"},{"doc":"Performs a partialy matched crossover of p1 and p2. Returns {%Chromosome{}, %Chromosome{}}. Parameters p1: Parent one. p2: Parent two.","ref":"Genex.Tools.Crossover.html#partialy_matched/2","title":"Genex.Tools.Crossover.partialy_matched/2","type":"function"},{"doc":"Performs a simulated binary crossover. Returns {%Chromosome{}, %Chromosome{}}. Parameters p1: Parent one. p2: Parent two. eta: Float","ref":"Genex.Tools.Crossover.html#simulated_binary/3","title":"Genex.Tools.Crossover.simulated_binary/3","type":"function"},{"doc":"Performs single point crossover at a random point. This will swap a random slice of genes from each chromosome, producing 2 new chromosomes. Returns {%Chromosome{}, %Chromosome{}}. Parameters p1: Parent one. p2: Parent two.","ref":"Genex.Tools.Crossover.html#single_point/2","title":"Genex.Tools.Crossover.single_point/2","type":"function"},{"doc":"Performs two-point crossover at a random point. This will swap two random slices of genes from each chromosome, producing 2 new chromosomes. Returns %Chromosome{}. Parameters p1: Parent one. p2: Parent two.","ref":"Genex.Tools.Crossover.html#two_point/2","title":"Genex.Tools.Crossover.two_point/2","type":"function"},{"doc":"Performs uniform crossover. This will swap random genes from each chromosome according to some specified rate, producing 2 new chrmosomes. Returns Chromosome. Parameters p1: Parent one. p2: Parent two. probability: Float between 0 and 1 representing rates to swap genes.","ref":"Genex.Tools.Crossover.html#uniform/3","title":"Genex.Tools.Crossover.uniform/3","type":"function"},{"doc":"Performs a uniform partialy matched crossover of p1 and p2. Returns {%Chromosome{}, %Chromosome{}}. Parameters p1: Parent one. p2: Parent two. probability: Probability of swap during PMX.","ref":"Genex.Tools.Crossover.html#uniform_partialy_matched/3","title":"Genex.Tools.Crossover.uniform_partialy_matched/3","type":"function"},{"doc":"Implementation of several population mutation methods. Mutation takes place according to some rate. Mutation is useful for introducing novelty into the population. This ensures your solutions don&#39;t prematurely converge. Future versions of Genex will provide the ability to define the &quot;aggressiveness&quot; of mutations. As of this version of Genex, mutations effect the ENTIRE chromosome.","ref":"Genex.Tools.Mutation.html","title":"Genex.Tools.Mutation","type":"module"},{"doc":"Perform a bit-flip mutation. This mutation performs a binary XOR on every gene in the Chromosome. Returns Chromosome. Parameters chromosome: Chromosome to mutate.","ref":"Genex.Tools.Mutation.html#bit_flip/1","title":"Genex.Tools.Mutation.bit_flip/1","type":"function"},{"doc":"Perform a bit-flip mutation. This mutation performs a binary XOR on a gene with probability p in the Chromosome. Returns Chromosome. Parameters chromosome: Chromosome to mutate. p: Probability of bitflip.","ref":"Genex.Tools.Mutation.html#bit_flip/2","title":"Genex.Tools.Mutation.bit_flip/2","type":"function"},{"doc":"Performs creep mutation. This mutation generates a random number between min and max at every gene in the chromosome. Returns Chromosome. Parameters chromosome: Chromosome to mutate. min: lower bound max: upper bound","ref":"Genex.Tools.Mutation.html#creep/3","title":"Genex.Tools.Mutation.creep/3","type":"function"},{"doc":"Performs creep mutation with at random genes. This mutation generates a random number between min and max at genes with probability p in the chromosome. Returns Chromosome. Parameters chromosome: Chromosome to mutate. p: Probability of mutation. min: lower bound max: upper bound","ref":"Genex.Tools.Mutation.html#creep/4","title":"Genex.Tools.Mutation.creep/4","type":"function"},{"doc":"Performs a gaussian mutation. This mutation generates a random number at every gene in the chromosome. The random number is from a normal distribution produced from the mean and variance of the genes in the chromosome. Returns Chromosome. Parameters chromosome: Chromosome to mutate.","ref":"Genex.Tools.Mutation.html#gaussian/1","title":"Genex.Tools.Mutation.gaussian/1","type":"function"},{"doc":"Performs a gaussian mutation at random genes. This mutation generates a random number at random genes with probability p in the chromosome. The random number is from a normal distribution produced from the mean and variance of the genes in the chromosome. Returns Chromosome. Parameters chromosome: Chromosome to mutate. p: Probability of mutation.","ref":"Genex.Tools.Mutation.html#gaussian/2","title":"Genex.Tools.Mutation.gaussian/2","type":"function"},{"doc":"Perform a scramble mutation. This mutation scrambles the genes of the Chromosome. Returns %Chromosome{}. Parameters chromosome: Chromosome to mutate.","ref":"Genex.Tools.Mutation.html#scramble/1","title":"Genex.Tools.Mutation.scramble/1","type":"function"},{"doc":"Perform a scramble mutation on a random slice of size n. This mutation scrambles the genes of the Chromosome between two random points. Returns %Chromosome{}. Parameters chromosome: Chromosome to mutate.","ref":"Genex.Tools.Mutation.html#scramble/2","title":"Genex.Tools.Mutation.scramble/2","type":"function"},{"doc":"Implementation of several popular selection methods. Selection occurs in two stages in Genex: parent selection and survivor selection. Parent Selection dictates which chromosomes are to be reserved for crossover according to some crossover rate. In this stage, a number of chromosomes are selected and paired off in 2-tuples in the order they are selected. Future versions of Genex will provide more advanced methods of parent selection. Survivor Selection occurs last in the GA cycle. As of this version of Genex, the survivor rate is always equal to 1 - CR where CR is the crossover rate. Future versions will support more advanced survivor selection, including the ability to fluctuate the population according to some operators.","ref":"Genex.Tools.Selection.html","title":"Genex.Tools.Selection","type":"module"},{"doc":"Natural selection of some number of chromosomes. This will select the n best (fittest) chromosomes. Returns Enum.t. Parameters chromosomes: Enum of Chromosomes. n: Number of chromosomes to select.","ref":"Genex.Tools.Selection.html#natural/2","title":"Genex.Tools.Selection.natural/2","type":"function"},{"doc":"Random selection of some number of chromosomes. This will select n random chromosomes. Returns Enum.t. Parameters chromosomes: Enum of Chromosomes. n: Number of chromosomes to select.","ref":"Genex.Tools.Selection.html#random/2","title":"Genex.Tools.Selection.random/2","type":"function"},{"doc":"Roulette selection of some number of chromosomes. This will select n chromosomes using a &quot;roulette&quot; wheel where the probability of a chromosome being selected is proportional to it&#39;s fitness. Returns Enum.t(). Parameters chromosomes: Enum of Chromosomes. n: Number of chromosomes to select.","ref":"Genex.Tools.Selection.html#roulette/2","title":"Genex.Tools.Selection.roulette/2","type":"function"},{"doc":"Stochastic Universal Sampling of chromosomes. This will sample all of the chromosomes without bias, choosing them at evenly spaced intervals. Returns Enum.t(). Parameters chromosomes: Enum of Chromosomes. n: Number of chromomsomes to select.","ref":"Genex.Tools.Selection.html#stochastic_universal_sampling/2","title":"Genex.Tools.Selection.stochastic_universal_sampling/2","type":"function"},{"doc":"Tournament selection of some number of chromosomes. This will select n chromosomes from tournaments of size k. We randomly select k chromosomes from the population and choose the max to be in the tournament. Returns Enum.t(). Parameters chromosomes: Enum of Chromosomes. n: Number of chromosomes to select. tournsize: The size of the tournament to run.","ref":"Genex.Tools.Selection.html#tournament/3","title":"Genex.Tools.Selection.tournament/3","type":"function"},{"doc":"Worst selection of some number of chromosomes. This will select the n worst (least fit) chromosomes. Returns Enum.t. Parameters chromosomes: Enum of Chromosomes. n: Number of chromosomes to select.","ref":"Genex.Tools.Selection.html#worst/2","title":"Genex.Tools.Selection.worst/2","type":"function"},{"doc":"Contains functions for generating various Genotypes. These are most of the genotypes you will use in basic genetic algorithms.","ref":"Genex.Tools.Genotype.html","title":"Genex.Tools.Genotype","type":"module"},{"doc":"Creates a binary geneset. Returns Enum.t(). Parameters size: Size of the geneset.","ref":"Genex.Tools.Genotype.html#binary/1","title":"Genex.Tools.Genotype.binary/1","type":"function"},{"doc":"Creates a bitstring geneset. Returns Enum.t(). Parameters size: Size of the geneset. alphabet: Alphabet to use.","ref":"Genex.Tools.Genotype.html#bitstring/2","title":"Genex.Tools.Genotype.bitstring/2","type":"function"},{"doc":"Creates a geneset from given distribution. Returns Enum.t(). Parameters size: Size of the geneset. name: Distribution name. args: Optional arguments to provide to distribution.","ref":"Genex.Tools.Genotype.html#distribution/3","title":"Genex.Tools.Genotype.distribution/3","type":"function"},{"doc":"Creates a permutation genotype. Returns Enum.t(). Parameters values: Possible values in the permutation.","ref":"Genex.Tools.Genotype.html#permutation/1","title":"Genex.Tools.Genotype.permutation/1","type":"function"},{"doc":"Evolution behaviour definition for Evolutionary algorithms. Evolutions begin with init after the population has been created. The purpose of init is to define metrics, initiate a genealogy tree, and create a hall of fame. init is like the &quot;constructor&quot; of the evolution.","ref":"Genex.Evolution.html","title":"Genex.Evolution","type":"behaviour"},{"doc":"Evaluates population according to fitness_fn.","ref":"Genex.Evolution.html#c:evaluation/2","title":"Genex.Evolution.evaluation/2","type":"callback"},{"doc":"Initialization of the evolution.","ref":"Genex.Evolution.html#c:init/2","title":"Genex.Evolution.init/2","type":"callback"},{"doc":"Recombine population.","ref":"Genex.Evolution.html#c:reinsertion/2","title":"Genex.Evolution.reinsertion/2","type":"callback"},{"doc":"Select parents for variation. Must populate selected field in Population.","ref":"Genex.Evolution.html#c:selection/2","title":"Genex.Evolution.selection/2","type":"callback"},{"doc":"Termination of the evolution.","ref":"Genex.Evolution.html#c:termination/2","title":"Genex.Evolution.termination/2","type":"callback"},{"doc":"Perform housekeeping before next generation. Includes Gene Repair.","ref":"Genex.Evolution.html#c:transition/2","title":"Genex.Evolution.transition/2","type":"callback"},{"doc":"Perform variation such as Crossover, Mutation, and Migration.","ref":"Genex.Evolution.html#c:variation/2","title":"Genex.Evolution.variation/2","type":"callback"},{"doc":"Models the most basic form of evolution.","ref":"Genex.Evolution.Simple.html","title":"Genex.Evolution.Simple","type":"module"},{"doc":"","ref":"Genex.Evolution.Simple.html#crossover/2","title":"Genex.Evolution.Simple.crossover/2","type":"function"},{"doc":"Callback implementation for Genex.Evolution.evaluation/2.","ref":"Genex.Evolution.Simple.html#evaluation/2","title":"Genex.Evolution.Simple.evaluation/2","type":"function"},{"doc":"","ref":"Genex.Evolution.Simple.html#evolve/3","title":"Genex.Evolution.Simple.evolve/3","type":"function"},{"doc":"Callback implementation for Genex.Evolution.init/2.","ref":"Genex.Evolution.Simple.html#init/2","title":"Genex.Evolution.Simple.init/2","type":"function"},{"doc":"","ref":"Genex.Evolution.Simple.html#mutation/2","title":"Genex.Evolution.Simple.mutation/2","type":"function"},{"doc":"Callback implementation for Genex.Evolution.reinsertion/2.","ref":"Genex.Evolution.Simple.html#reinsertion/2","title":"Genex.Evolution.Simple.reinsertion/2","type":"function"},{"doc":"Callback implementation for Genex.Evolution.selection/2.","ref":"Genex.Evolution.Simple.html#selection/2","title":"Genex.Evolution.Simple.selection/2","type":"function"},{"doc":"Callback implementation for Genex.Evolution.termination/2.","ref":"Genex.Evolution.Simple.html#termination/2","title":"Genex.Evolution.Simple.termination/2","type":"function"},{"doc":"Callback implementation for Genex.Evolution.transition/2.","ref":"Genex.Evolution.Simple.html#transition/2","title":"Genex.Evolution.Simple.transition/2","type":"function"},{"doc":"Benchmark objective functions for binary genetic algorithms.","ref":"Genex.Tools.Benchmarks.Binary.html","title":"Genex.Tools.Benchmarks.Binary","type":"module"},{"doc":"","ref":"Genex.Tools.Benchmarks.Binary.html#chuang_f1/0","title":"Genex.Tools.Benchmarks.Binary.chuang_f1/0","type":"function"},{"doc":"","ref":"Genex.Tools.Benchmarks.Binary.html#chuang_f2/0","title":"Genex.Tools.Benchmarks.Binary.chuang_f2/0","type":"function"},{"doc":"","ref":"Genex.Tools.Benchmarks.Binary.html#chuang_f3/0","title":"Genex.Tools.Benchmarks.Binary.chuang_f3/0","type":"function"},{"doc":"Royal Road objective function. Returns math. Parameters chromosome: %Chromosome{}. order: Integer.","ref":"Genex.Tools.Benchmarks.Binary.html#royal_road1/2","title":"Genex.Tools.Benchmarks.Binary.royal_road1/2","type":"function"},{"doc":"Royal Road 2 objective function. Returns math. Parameters chromosome: %Chromosome{}. order: Integer.","ref":"Genex.Tools.Benchmarks.Binary.html#royal_road2/2","title":"Genex.Tools.Benchmarks.Binary.royal_road2/2","type":"function"},{"doc":"Provides benchmark functions for Single Objective Continuous optimization problems. These functions haven&#39;t been tested. More documentation/testing is coming later.","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous","type":"module"},{"doc":"Ackley objective function. Returns math. Parameters xs: Enum.","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#ackley/1","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.ackley/1","type":"function"},{"doc":"Bohachevsky objective function. Returns math. Paramters xs: Enum.","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#bohachevsky/1","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.bohachevsky/1","type":"function"},{"doc":"Cigar objective function. Returns math. Parameters xs: Enum.","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#cigar/1","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.cigar/1","type":"function"},{"doc":"Griewank objective function. Returns math. Parameters xs: Enum.","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#griewank/1","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.griewank/1","type":"function"},{"doc":"h1 objective function. Returns math. Parameters x: number. y: number.","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#h1/2","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.h1/2","type":"function"},{"doc":"Himmelblau objective function. Returns math. Paramters x: number. y: number.","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#himmelblau/2","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.himmelblau/2","type":"function"},{"doc":"Plane objective function. Returns math. Parameters xs: Enum.","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#plane/1","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.plane/1","type":"function"},{"doc":"Random objective function. Returns math. Parameters xs: Enum.","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#rand/1","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.rand/1","type":"function"},{"doc":"Rastrigin objective function. Returns math. Parameters xs: Enum.","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#rastrigin/1","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.rastrigin/1","type":"function"},{"doc":"Rosebrock objective function. Returns math. Parameters xs: Enum.","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#rosenbrock/1","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.rosenbrock/1","type":"function"},{"doc":"","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#schaffer/0","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.schaffer/0","type":"function"},{"doc":"","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#schwefel/0","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.schwefel/0","type":"function"},{"doc":"","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#shekel/0","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.shekel/0","type":"function"},{"doc":"Sphere objective function. Returns math. Parameters xs: Enum.","ref":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.html#sphere/1","title":"Genex.Tools.Benchmarks.SingleObjectiveContinuous.sphere/1","type":"function"},{"doc":"Provides benchmark functions for Symbolic Regression programs with Genetic Programming. These functions haven&#39;t been tested. More documentation/testing is coming later.","ref":"Genex.Tools.Benchmarks.SymbolicRegression.html","title":"Genex.Tools.Benchmarks.SymbolicRegression","type":"module"},{"doc":"Kotanchek benchmark. Returns math. Parameters x: number. y: number.","ref":"Genex.Tools.Benchmarks.SymbolicRegression.html#kotanchek/2","title":"Genex.Tools.Benchmarks.SymbolicRegression.kotanchek/2","type":"function"},{"doc":"Rational polynomial benchmark functon. Returns math. Parameters x: number. y: number. z: number.","ref":"Genex.Tools.Benchmarks.SymbolicRegression.html#rational_polynomial/3","title":"Genex.Tools.Benchmarks.SymbolicRegression.rational_polynomial/3","type":"function"},{"doc":"Rational polynomial in 2 dimensions benchmark function. Returns math. Parameters x: number. y: number.","ref":"Genex.Tools.Benchmarks.SymbolicRegression.html#rational_polynomial2/2","title":"Genex.Tools.Benchmarks.SymbolicRegression.rational_polynomial2/2","type":"function"},{"doc":"Ripple benchmark function. Returns math. Parameters x: number y: number","ref":"Genex.Tools.Benchmarks.SymbolicRegression.html#ripple/2","title":"Genex.Tools.Benchmarks.SymbolicRegression.ripple/2","type":"function"},{"doc":"Salustowicz 1-D benchmark function. Returns math. Parameters x: number.","ref":"Genex.Tools.Benchmarks.SymbolicRegression.html#salustowicz_1d/1","title":"Genex.Tools.Benchmarks.SymbolicRegression.salustowicz_1d/1","type":"function"},{"doc":"Salustowicz 2-D benchmark function. Returns math. Parameters x: number. y: number.","ref":"Genex.Tools.Benchmarks.SymbolicRegression.html#salustowicz_2d/2","title":"Genex.Tools.Benchmarks.SymbolicRegression.salustowicz_2d/2","type":"function"},{"doc":"Sine-Cosine benchmark function. Returns math. Parameters x: number. y: number.","ref":"Genex.Tools.Benchmarks.SymbolicRegression.html#sin_cos/2","title":"Genex.Tools.Benchmarks.SymbolicRegression.sin_cos/2","type":"function"},{"doc":"Unwrapped Ball benchmark function. Returns math. Parameters xs: Enum of number.","ref":"Genex.Tools.Benchmarks.SymbolicRegression.html#unwrapped_ball/1","title":"Genex.Tools.Benchmarks.SymbolicRegression.unwrapped_ball/1","type":"function"},{"doc":"Evaluation convenience functions.","ref":"Genex.Tools.Evaluation.html","title":"Genex.Tools.Evaluation","type":"module"},{"doc":"Interactive fitness for interactive genetic algorithms. Requires an input buffer, a prompt, and a chromosome. Returns Integer. Parameters buffer: Input buffer. prompt: Message prompt. Chromosome: %Chromosome{}.","ref":"Genex.Tools.Evaluation.html#interactive/3","title":"Genex.Tools.Evaluation.interactive/3","type":"function"},{"doc":"Convenience functions for Multi-Objective Optimization. Most of these functions aren&#39;t tested yet.","ref":"Genex.Tools.Evaluation.Indicator.html","title":"Genex.Tools.Evaluation.Indicator","type":"module"},{"doc":"Determines if c1 dominates c2.","ref":"Genex.Tools.Evaluation.Indicator.html#dominates?/2","title":"Genex.Tools.Evaluation.Indicator.dominates?/2","type":"function"},{"doc":"Penalty functions for use with constraint satisfaction problems. Returns the chromosome so you can easily cascade constraints. Example def fitness_function(c) do c |&gt; Penalty.delta(...) |&gt; Penalty.delta(...) |&gt; eval() end eval/1 is a convenience function for returning fitness from a chromosome.","ref":"Genex.Tools.Evaluation.Penalty.html","title":"Genex.Tools.Evaluation.Penalty","type":"module"},{"doc":"Closest-Valid penalty function. Returns %Chromosome{}. Parameters individual: %Chromosome{}. feasibiliy: Function. feasible: feasible chromosome. alpha: number distance: Function.","ref":"Genex.Tools.Evaluation.Penalty.html#closest_valid/5","title":"Genex.Tools.Evaluation.Penalty.closest_valid/5","type":"function"},{"doc":"Delta penalty function. Returns %Chromosome{}. Parameters individual: %Chromosome{}. feasibiliy: Function. delta: penalty. distance: Function.","ref":"Genex.Tools.Evaluation.Penalty.html#delta/4","title":"Genex.Tools.Evaluation.Penalty.delta/4","type":"function"},{"doc":"Utilities for saving and loading from checkpoints. Checkpoints are useful if you want to start and stop an evolution from a previous evolution with different parameters. These functions haven&#39;t been tested. Documentation/Testing coming soon.","ref":"Genex.Support.Checkpoint.html","title":"Genex.Support.Checkpoint","type":"module"},{"doc":"","ref":"Genex.Support.Checkpoint.html#export/2","title":"Genex.Support.Checkpoint.export/2","type":"function"},{"doc":"Loads a checkpoint from path. Returns %Population{}. Parameters path: Path to checkpoint zipfile.","ref":"Genex.Support.Checkpoint.html#load/1","title":"Genex.Support.Checkpoint.load/1","type":"function"},{"doc":"Implementation of a genealogy tree. We use the Genealogy tree to model the history of the population from it&#39;s initialization to the end of the algorithm. The tree itself is a directed Graph implemented using libgraph. Genealogy is tracked in a population struct, so you can access the genealogy anytime through the current population. Any function in the libgraph library will work on a genealogy An edge emanates from parent and is incident on child. Mutants are considered new chromosomes, so their lineage starts with a single parent. To produce visualizations of the Genealogy of an evolution, you&#39;ll have to export the tree to a DOT file and use a third-party visualization tool.","ref":"Genex.Support.Genealogy.html","title":"Genex.Support.Genealogy","type":"module"},{"doc":"Exports the genealogy tree. Returns {:ok, String}. Parameters genealogy: Reference to a Genealogy Tree.","ref":"Genex.Support.Genealogy.html#export/1","title":"Genex.Support.Genealogy.export/1","type":"function"},{"doc":"Creates a new Genealogy Tree. Returns Graph.","ref":"Genex.Support.Genealogy.html#new/0","title":"Genex.Support.Genealogy.new/0","type":"function"},{"doc":"Updates a Genealogy Tree with several vertices or one vertex. Returns Graph. Parameters genealogy: Reference to the Genealogy Tree. chromosomes: List of %Chromosome{} or %Chromosome{}.","ref":"Genex.Support.Genealogy.html#update/2","title":"Genex.Support.Genealogy.update/2","type":"function"},{"doc":"Updates a Genealogy Tree with a vertex and it&#39;s parents. Returns Graph. # Parameters - `genealogy`: Reference to a Genealogy Tree. - `child`: Child `%Chromosome{}`. - `parent`: Parent `%Chromosome{}`.","ref":"Genex.Support.Genealogy.html#update/3","title":"Genex.Support.Genealogy.update/3","type":"function"},{"doc":"Updates a Genealogy Tree with a vertex and it&#39;s parents. Returns Graph. Parameters genealogy: Reference to a Genealogy Tree. child: Child %Chromosome{}. parent_a: Parent A %Chromosome{}. parent_b: Parent B %Chromosome{}.","ref":"Genex.Support.Genealogy.html#update/4","title":"Genex.Support.Genealogy.update/4","type":"function"},{"doc":"Keeps track of the strongest individual of a generation in an ETS table. The hall of fame makes it easy to track the strongest individual between generations. It&#39;s a simple ETS table with the Key-Value pair of {Generation, Chromosome}. The hall of fame can be accessed at anytime as an ETS named table with name :hall_of_fame.","ref":"Genex.Support.HallOfFame.html","title":"Genex.Support.HallOfFame","type":"module"},{"doc":"Add a generation to Hall of Fame. This will add the current generation and strongest chromosome for a generation. Returns :ok. Parameters population: %Population{} to add.","ref":"Genex.Support.HallOfFame.html#add/1","title":"Genex.Support.HallOfFame.add/1","type":"function"},{"doc":"Exports the named table to a file. This function is kind of broken. Returns {:ok, fname}. Parameters path: Path to save to. Defaults to current directory.","ref":"Genex.Support.HallOfFame.html#export/0","title":"Genex.Support.HallOfFame.export/0","type":"function"},{"doc":"Create a new Hall of Fame. This will create an ETS named table called, :hall_of_fame. Returns :ok.","ref":"Genex.Support.HallOfFame.html#new/0","title":"Genex.Support.HallOfFame.new/0","type":"function"},{"doc":"Genex representation of a single solution. A Chromosome represents one solution to the problem you are trying to solve. Solutions are encoded into a collection of genes. The Chromosome is then evaluated based on some criteria you define. Chromosomes in Genex can be defined as very &quot;self-aware.&quot; That is to say: they contain all of the information necessary to repair and evaluate themselves. This fact can be used for some interesting applications.","ref":"Genex.Types.Chromosome.html","title":"Genex.Types.Chromosome","type":"module"},{"doc":"Chromosome type. Chromosomes are represented as a %Chromosome{}. At a minimum a chromosome needs :genes, :f, and :collection. Fields :genes: Enum containing genotype representation. :size: non_neg_integer representing size of chromosome. :age: non_neg_integer representing age of chromosome. :fitness: number or Enum representing fitness(es) of chromosome. :weights: number or Enum representing weights of each objective. :f: Function used to evaluate chromosome. :collection: Function used to store chromosome.","ref":"Genex.Types.Chromosome.html#t:t/0","title":"Genex.Types.Chromosome.t/0","type":"type"},{"doc":"A collection of Chromosomes. The Population represents the pool of solutions you are trying to optimize. Ideally, you persist the &#39;fittest&#39; features from generation to generation until you converge on a solution. The Population struct contains a number of useful fields that can be analyzed after the algorithm runs.","ref":"Genex.Types.Population.html","title":"Genex.Types.Population","type":"module"},{"doc":"","ref":"Genex.Types.Population.html#t:t/0","title":"Genex.Types.Population.t/0","type":"type"},{"doc":"Behaviour for implementing visualizations. A visualizer provides robust visualization for your genetic algorithms. A complete visualizer behaviour implements two functions: init/1 and display/2. The visualizer behaviour also implements String.Chars for both Chromosome and Population. You can override these defualt implementations in your visualizer module. The options passed to your visualizer is a Keyword list that is the same as the initial options passed to run/1. You can specify any required options in your own visualizer module. Example Implementation The following is a basic correct implementation of a Genex visualizer. defmodule MyVisualizer do use Genex.Visualizer def init(_) do IO.write(&quot;Beginning Algorithm...&quot;) :ok end def display(population), do: IO.inspect(population) end","ref":"Genex.Visualizer.html","title":"Genex.Visualizer","type":"behaviour"},{"doc":"Displays a summary of the population. This function takes a %Population{} and returns any value representing a visualization of the population. Typically, this is a summary of the population during the current generation. By default, display/2 is called at the beginning of every new generation.","ref":"Genex.Visualizer.html#c:display/2","title":"Genex.Visualizer.display/2","type":"callback"},{"doc":"Initializes the visualizer with opts. The purpose of this function is to do any initial setup of your visualizer. For example, in the Text visualizer, init/1 is responsible for outputting the initial table layout. You can do anything you want in init/1, so long as it returns :ok.","ref":"Genex.Visualizer.html#c:init/1","title":"Genex.Visualizer.init/1","type":"callback"}]